==> qastools_1.1.0.orig.tar.xz: qastools-v1.1.0/qashctl/src/mwdg/mixer_hctl_table_model.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include <QAbstractTableModel>
#include <QStringList>
#include <vector>

// Forward declaration
namespace QSnd
{
class Mixer_HCTL;
class Mixer_HCTL_Elem;
class Mixer_HCTL_Elem_Group;
} // namespace QSnd

namespace MWdg
{

/// @brief Mixer_HCTL_Table_Model
///
class Mixer_HCTL_Table_Model : public QAbstractTableModel
{
  Q_OBJECT;

  // Public methods
  public:
  // -- Construction

  Mixer_HCTL_Table_Model ( QObject * parent_n = nullptr );

  ~Mixer_HCTL_Table_Model ();

  // -- Mixer class

  ::QSnd::Mixer_HCTL *
  snd_mixer () const
  {
    return _snd_mixer;
  }

  void
  set_snd_mixer ( ::QSnd::Mixer_HCTL * snd_mixer_n );

  // Interface type index

  unsigned int
  iface_type_idx () const
  {
    return _iface_type_idx;
  }

  void
  set_iface_type_idx ( unsigned int type_n );

  ::QSnd::Mixer_HCTL_Elem *
  elem ( const QModelIndex & idx_n ) const;

  int
  rowCount ( const QModelIndex & parent_n = QModelIndex () ) const;

  int
  columnCount ( const QModelIndex & parent_n = QModelIndex () ) const;

  QVariant
  data ( const QModelIndex & index_n, int role_n = Qt::DisplayRole ) const;

  QVariant
  headerData ( int section_n,
               Qt::Orientation orientation_n,
               int role_n = Qt::DisplayRole ) const;

  // Protected methods
  protected:
  void
  clear ();

  void
  load ();

  // Private attributes
  private:
  ::QSnd::Mixer_HCTL * _snd_mixer;

  ::std::vector< ::QSnd::Mixer_HCTL_Elem * > _elems;

  unsigned int _iface_type_idx;

  QString _str_dev_mask;
  QString _ttip_dev;
  QString _ttip_name_mask;

  QString _col_names[ 7 ];
  QString _col_ttips[ 7 ];

  const unsigned int _num_columns;
  const Qt::Alignment _align_cc;
  const Qt::Alignment _align_lc;
};

} // namespace MWdg

==> qastools_1.2.0.orig.tar.xz: qastools-v1.2.0/qashctl/src/mwdg/mixer_hctl_table_model.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include <QAbstractTableModel>
#include <QStringList>
#include <vector>

// Forward declaration
namespace QSnd::HCtl
{
class Mixer;
class Elem;
class Elem_Group;
} // namespace QSnd::HCtl

namespace MWdg
{

/// @brief Mixer_HCTL_Table_Model
///
class Mixer_HCTL_Table_Model : public QAbstractTableModel
{
  Q_OBJECT;

  public:
  // -- Construction

  Mixer_HCTL_Table_Model ( QObject * parent_n = nullptr );

  ~Mixer_HCTL_Table_Model ();

  // -- Mixer class

  QSnd::HCtl::Mixer *
  snd_mixer () const
  {
    return _snd_mixer;
  }

  void
  set_snd_mixer ( QSnd::HCtl::Mixer * snd_mixer_n );

  // Interface type index

  unsigned int
  iface_type_idx () const
  {
    return _iface_type_idx;
  }

  void
  set_iface_type_idx ( unsigned int type_n );

  QSnd::HCtl::Elem *
  elem ( const QModelIndex & idx_n ) const;

  int
  rowCount ( const QModelIndex & parent_n = QModelIndex () ) const;

  int
  columnCount ( const QModelIndex & parent_n = QModelIndex () ) const;

  QVariant
  data ( const QModelIndex & index_n, int role_n = Qt::DisplayRole ) const;

  QVariant
  headerData ( int section_n,
               Qt::Orientation orientation_n,
               int role_n = Qt::DisplayRole ) const;

  protected:
  // -- Protected methods

  void
  clear ();

  void
  load ();

  private:
  // -- Attributes
  QSnd::HCtl::Mixer * _snd_mixer;

  std::vector< QSnd::HCtl::Elem * > _elems;

  unsigned int _iface_type_idx;

  QString _str_dev_mask;
  QString _ttip_dev;
  QString _ttip_name_mask;

  QString _col_names[ 7 ];
  QString _col_ttips[ 7 ];

  const unsigned int _num_columns;
  const Qt::Alignment _align_cc;
  const Qt::Alignment _align_lc;
};

} // namespace MWdg
